/*
 * MapInterface.java
 * 
 * Created on April 17, 2002, 7:23 PM Last edited on October 12, 2002
 */
package nl.javel.gisbeans.map;

import java.awt.Graphics2D;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.rmi.RemoteException;
import java.util.List;

import nl.javel.gisbeans.geom.SerializableRectangle2D;

/**
 * This interface defines the map.
 * 
 * @author <a href="mailto:paul.jacobs@javel.nl">Paul Jacobs </a>
 * @since JDK 1.0
 * @version 1.0
 */
public interface MapInterface extends java.io.Serializable
{
	/** MINX contant */
	public static final byte MINX = 0;

	/** MINY contant */
	public static final byte MINY = 1;

	/** MAXX contant */
	public static final byte MAXX = 2;

	/** MAXY contant */
	public static final byte MAXY = 3;

	/** FEET contant */
	public static final byte FEET = 0;

	/** INCHES contant */
	public static final byte INCHES = 1;

	/** KILOMETERS contant */
	public static final byte KILOMETERS = 2;

	/** METERS contant */
	public static final byte METERS = 3;

	/** MILES contant */
	public static final byte MILES = 4;

	/** DD contant */
	public static final byte DD = 5;

	/** UL */
	public static final byte UL = 0;

	/** UC */
	public static final byte UC = 1;

	/** UR */
	public static final byte UR = 2;

	/** CL */
	public static final byte CL = 3;

	/** CC */
	public static final byte CC = 4;

	/** CR */
	public static final byte CR = 5;

	/** LL */
	public static final byte LL = 6;

	/** LC */
	public static final byte LC = 7;

	/** LR */
	public static final byte LR = 8;

	/** TEXT */
	public static final byte TEXT = 0;

	/** ANGLEDEG */
	public static final byte ANGLEDEG = 1;

	/** ANGLERAD */
	public static final byte ANGLERAD = 2;

	/** IMAGE */
	public static final byte IMAGE = 3;

	/** AIRPHOTO */
	public static final byte AIRPHOTO = 4;

	/** POLYGON */
	public static final byte POLYGON = 0;

	/** POINT */
	public static final byte POINT = 1;

	/** LINE */
	public static final byte LINE = 2;

	/** FEET_TO_METER */
	public static final double FEET_TO_METER = 0.3048;

	/** INCH_TO_METER */
	public static final double INCH_TO_METER = 0.0254;

	/** KILOMETER_TO_METER */
	public static final double KILOMETER_TO_METER = 1000;

	/** MILES_TO_METER */
	public static final double MILES_TO_METER = 1609.34;

	/** DD_TO_METER */
	public static final double DD_TO_METER = 111119;

	/** CENTIMETER_PER_INCH */
	public static final double CENTIMETER_PER_INCH = 2.54;

	/**
	 * draws the legend on a graphics object
	 * 
	 * @return Graphics2D
	 * @param graphics the graphics object
	 * @throws GraphicsException on drawing failure
	 * @throws RemoteException on network failure
	 */
	public Graphics2D drawLegend(Graphics2D graphics) throws GraphicsException,
			RemoteException;

	/**
	 * draws the map on a graphics object
	 * 
	 * @param graphics the graphics object
	 * @return Graphics2D
	 * @throws GraphicsException on drawing failure
	 * @throws RemoteException on network failure
	 */
	public Graphics2D drawMap(Graphics2D graphics) throws GraphicsException,
			RemoteException;

	/**
	 * draws the reference map on a graphics object
	 * 
	 * @param graphics the graphics object
	 * @return Graphics2D
	 * @throws GraphicsException on drawing failure
	 * @throws RemoteException on network failure
	 */
	public Graphics2D drawReferenceMap(Graphics2D graphics)
			throws GraphicsException, RemoteException;

	/**
	 * draws the scalebar on a graphics object
	 * 
	 * @param graphics the graphics object
	 * @return Graphics2D
	 * @throws GraphicsException on drawing failure
	 * @throws RemoteException on network failure
	 */
	public Graphics2D drawScalebar(Graphics2D graphics)
			throws GraphicsException, RemoteException;

	/**
	 * Getter for property extent
	 * 
	 * @return the extent of the map
	 * @throws RemoteException on network exception
	 */
	public Rectangle2D getExtent() throws RemoteException;

	/**
	 * Getter for property image
	 * 
	 * @return ImageInterface the value of property image.
	 * @throws RemoteException on network exception
	 */
	public ImageInterface getImage() throws RemoteException;

	/**
	 * Getter for property layers
	 * 
	 * @return List the value of property layers.
	 * @throws RemoteException on network exception
	 */
	public List getLayers() throws RemoteException;

	/**
	 * Getter for property name
	 * 
	 * @return String the value of property extent.
	 * @throws RemoteException on network exception
	 */
	public String getName() throws RemoteException;

	/**
	 * Getter for property referenceMap
	 * 
	 * @return ReferenceMap the value of property referenceMap.
	 * @throws RemoteException on network exception
	 */
	public ReferenceMapInterface getReferenceMap() throws RemoteException;

	/**
	 * returns the sclale of the map
	 * 
	 * @return double the scale of the map in its units
	 * @throws RemoteException on network exception
	 */
	public double getScale() throws RemoteException;

	/**
	 * returns the scale of the Image
	 * 
	 * @return double the unitPerPixel
	 * @throws RemoteException on network exception
	 */
	public double getUnitImageRatio() throws RemoteException;

	/**
	 * Getter for property units
	 * 
	 * @return int the value of property units.
	 * @throws RemoteException on network exception
	 */
	public int getUnits() throws RemoteException;

	/**
	 * Setter for property extent.
	 * 
	 * @param extent New value of property extent..
	 * @throws RemoteException on network exception
	 */
	public void setExtent(Rectangle2D extent) throws RemoteException;

	/**
	 * Setter for property image.
	 * 
	 * @param image New value of property image.
	 * @throws RemoteException on network exception
	 */
	public void setImage(ImageInterface image) throws RemoteException;

	/**
	 * Setter for property layers.
	 * 
	 * @param layers New value of property layers.
	 * @throws RemoteException on network exception
	 */
	public void setLayers(List layers) throws RemoteException;

	/**
	 * Setter for property layers.
	 * 
	 * @param index Index value of layer
	 * @param layer New value of property layers.
	 * @throws RemoteException on network exception
	 */
	public void setLayer(int index, LayerInterface layer)
			throws RemoteException;

	/**
	 * Setter for property layers.
	 * 
	 * @param layer New value of property layers.
	 * @throws RemoteException on network exception
	 */
	public void addLayer(LayerInterface layer) throws RemoteException;

	/**
	 * Setter for property name.
	 * 
	 * @param name New value of property name.
	 * @throws RemoteException on network exception
	 */
	public void setName(String name) throws RemoteException;

	/**
	 * Setter for property referenceMap.
	 * 
	 * @param referenceMap New value of property referenceMap.
	 * @throws RemoteException on network exception
	 */
	public void setReferenceMap(ReferenceMapInterface referenceMap)
			throws RemoteException;

	/**
	 * Setter for property units.
	 * 
	 * @param units New value of property units.
	 * @throws RemoteException on network exception
	 */
	public void setUnits(int units) throws RemoteException;

	/**
	 * zooms the map with a prticular factor
	 * 
	 * @param zoomFactor (0=1)
	 * @throws RemoteException on network exception
	 */
	public void zoom(double zoomFactor) throws RemoteException;

	/**
	 * zooms the map based on a given position in the image
	 * 
	 * @param pixelPosition the position in the image
	 * @param zoomFactor the zoomFactor (0=1)
	 * @throws RemoteException on network exception
	 */
	public void zoomPoint(Point2D pixelPosition, double zoomFactor)
			throws RemoteException;

	/**
	 * zooms the map based on a given rectangle
	 * 
	 * @param rectangle a rectangle in the map (image units)
	 * @throws RemoteException on network exception
	 */
	public void zoomRectangle(SerializableRectangle2D rectangle)
			throws RemoteException;

}